#############################################################################
#
# File:   MakeUnitTests.mk
# Author: Dave Hefner
# Date:   Jan. 8, 2013
#
# This file is used to build unit test binaries.
#
# Copyright (C) 2013 Hewlett-Packard Co.  All rights reserved.
#
#############################################################################

include $(WC_ROOT)/common.mk

HERE1:=$(subst /, ,$(abspath $(THIS_DIR)))
HERE:=$(lastword $(HERE1))

make-directories:=$(shell mkdir -p obj bin)

TEST_ROOT_DIR:=$(abspath $(CURDIR))
TEST_ROOT_NAME:=$(notdir $(CURDIR))

UT_LIB_ROOT:=$(abspath $(TEST_ROOT_DIR)/..)
UT_LIB_NAME:=$(basename $(notdir $(UT_LIB_ROOT)))

.SECONDEXPANSION:
.SUFFIXES:

.PHONY: clean indent

TEST_SRC_DIR := $(TEST_ROOT_DIR)/src
TEST_BIN_DIR := $(TEST_ROOT_DIR)/bin
TEST_OBJ_DIR := $(TEST_ROOT_DIR)/obj
TEST_SOURCES := $(wildcard $(TEST_SRC_DIR)/*.cpp)
TEST_OBJECTS := $(notdir $(TEST_SOURCES:.cpp=.o))
TEST_OBJECTS_PATH := $(addprefix $(TEST_OBJ_DIR)/,$(TEST_OBJECTS))

TEST_BINNAMES:=$(notdir $(TEST_SOURCES:.cpp=))
TEST_BINARIES:=$(addprefix $(abspath $(TEST_BIN_DIR))/, $(TEST_BINNAMES))

all: $(unitTestBinaries)
	-@$(MAKE) -k --no-print-directory unitTestBinaries

unitTestBinaries: $(TEST_BINARIES)
testObjects: $(TEST_OBJECTS_PATH)	

$(TEST_OBJECTS_PATH): $(TEST_OBJ_DIR)/%.o: $(TEST_SRC_DIR)/$$*.cpp
	${CXX} $(CXXFLAGS) $(CPPFLAGS) $(TARGET_ARCH) $< -o $@

$(TEST_BINARIES): $(L1_LIBS)

$(TEST_BINARIES): $(TEST_BIN_DIR)%: $(TEST_OBJ_DIR)$$*.o
	$(CXX) $(TARGET_ARCH) $< $(LDFLAGS) $(CC_LDFLAGS_RPATH) ${GMOCK_MAIN} $(LIBS) -o $@

ifneq "$(MAKECMDGOALS)" "clean"
    -include $(TEST_OBJ_DIR)/*.d
endif

binariesToRun:=$(wildcard $(TEST_BIN_DIR)/*)

check: $(unitTestBinaries)
	-@for t in $(binariesToRun); \
	do				\
		$$t --gtest_output=xml:$(UNIT_TEST_REPORT_DIR);	\
	done
	rm -rf $(TEST_BIN_DIR)/core*.*

indent:
	../../sbin/prettyCode.sh $(TEST_SOURCES)

clean:
	@rm -rf $(TEST_BIN_DIR)
	@rm -rf $(TEST_OBJ_DIR)
	@rm -f *.xml core* *.log *.lock

