
TOOL_CHAIN_DROP:=$(abspath /vduToolChain)
TOOL_CHAIN_BIN:=$(TOOL_CHAIN_DROP)/bin
TOOL_CHAIN_INCLUDE:=$(TOOL_CHAIN_DROP)/include
TOOL_CHAIN_LIB:=$(TOOL_CHAIN_DROP)/lib
TOOL_CHAIN_LIB64:=$(TOOL_CHAIN_DROP)/lib64
TOOL_CHAIN_PKG_CONFIG:=$(TOOL_CHAIN_LIB)/pkgconfig
TOOL_CHAIN_PKG_CONFIG64:=$(TOOL_CHAIN_LIB64)/pkgconfig
TOOLCHAIN_LD_LIBRARY_PATH:=$(TOOL_CHAIN_LIB):$(TOOL_CHAIN_LIB64)

TOOL_CHAIN_RPATH:=-Wl,-rpath=$(TOOL_CHAIN_LIB) -Wl,-rpath-link=$(TOOL_CHAIN_LIB)
TOOL_CHAIN_RPATH+=-Wl,-rpath=$(TOOL_CHAIN_LIB64) -Wl,-rpath-link=$(TOOL_CHAIN_LIB64)
CC_TOOL_CHAIN_RPATH:=-Wl,-rpath=$(TOOL_CHAIN_LIB) -Wl,-rpath-link=$(TOOL_CHAIN_LIB)
CC_TOOL_CHAIN_RPATH+=-Wl,-rpath=$(TOOL_CHAIN_LIB64) -Wl,-rpath-link=$(TOOL_CHAIN_LIB64)

BUILD_TOOLS_DROP:=$(realpath /vduBuildTools)
BUILD_TOOLS_LIB:=$(BUILD_TOOLS_DROP)/lib
BUILD_TOOLS_INC:=$(BUILD_TOOLS_DROP)/include
BUILD_TOOLS_LIB64:=$(BUILD_TOOLS_DROP)/lib64
BUILD_TOOLS_PKG_CONFIG:=$(BUILD_TOOLS_LIB)/pkgconfig
BUILD_TOOLS_PKG_CONFIG64:=$(BUILD_TOOLS_LIB64)/pkgconfig
BUILD_TOOLS_RPATH:=-Wl,-rpath=$(BUILD_TOOLS_LIB) -Wl,-rpath-link=$(BUILD_TOOLS_LIB)
BUILD_TOOLS_RPATH+=-Wl,-rpath=$(BUILD_TOOLS_LIB64) -Wl,-rpath-link=$(BUILD_TOOLS_LIB64)
BUILD_TOOLS_LD_LIBRARY_PATH:=$(BUILD_TOOLS_LIB):$(BUILD_TOOLS_LIB64)

LD_LIBRARY_PATH:=$(BUILD_TOOLS_LD_LIBRARY_PATH):$(TOOLCHAIN_LD_LIBRARY_PATH):$(LD_LIBRARY_PATH)

BULLSEYE_DIR:=$(abspath /vduBuildTools/BullseyeCoverage)
BULLSEYE_BIN:=$(BULLSEYE_DIR)/bin

ifeq "$(HARDWARE_PLATFORM)" "x86_64"
    BULLSEYE_COVERAGE_AVAILABLE:=1
    TARGET_ARCH:=-m64
else
    BULLSEYE_COVERAGE_AVAILABLE:=0
    TARGET_ARCH:=
endif

export CXX:=$(TOOL_CHAIN_BIN)/g++
ifeq "$(BULLSEYE_COVERAGE_AVAILABLE)" "1"
    ifeq "$(USE_BULLSEYE_COVERAGE)" "1"
        export COVFILE:=$(WC_ROOT)/L1.cov
        export CXX:=$(BULLSEYE_BIN)/covc -f$(COVFILE) --no-banner -i $(TOOL_CHAIN_BIN)/g++
        $(shell $(BULLSEYE_BIN)/cov01 --no-banner -1)
    else
        $(shell $(BULLSEYE_BIN)/cov01 --no-banner -0)
    endif
endif

CC:=$(TOOL_CHAIN_BIN)/gcc
LD:=$(TOOL_CHAIN_BIN)/ld
AR:=$(TOOL_CHAIN_BIN)/ar

CPPLANG:=-std=c++17
CLANG:=-std=c11 -fms-extensions

COMPILER_VER:=$(shell g++ --version)
#USE_SANITIZER:=$(if $(findstring 6.2,$(COMPILER_VER)),YES,NO)
#ifeq "$(USE_SANITIZER)" "YES"
#    SANITIZER:=-fsanitize=address
#    SANITIZER_LIB:=-lasan
#endif


TBB_KERNEL_STRING:=$(strip $(shell uname -r | awk -F'[.-]' '{ print $$1,$$2,$$3; }'))
empty:=
space:= $(empty) $(empty)
dot:= .
TBB_KERNEL_STR:=$(subst $(space),$(dot),$(TBB_KERNEL_STRING))
TBB_COMPILER_STR:=gcc_cc9.2.0
TBB_C_LIB_STR:=libc$(strip $(shell ldd --version | egrep '[2]\.[0-9]+$$' | awk '{ print $$4; }'))

ifeq "$(HARDWARE_PLATFORM)" "aarch64"
    X_REL:=$(BUILD_TOOLS_DROP)/linux_aarch64_$(TBB_COMPILER_STR)_$(TBB_C_LIB_STR)_kernel$(TBB_KERNEL_STR)_release
    X_DEB:=$(BUILD_TOOLS_DROP)/linux_aarch64_$(TBB_COMPILER_STR)_$(TBB_C_LIB_STR)_kernel$(TBB_KERNEL_STR)_debug
else
    X_REL:=$(BUILD_TOOLS_DROP)/linux_intel64_$(TBB_COMPILER_STR)_$(TBB_C_LIB_STR)_kernel$(TBB_KERNEL_STR)_release
    X_DEB:=$(BUILD_TOOLS_DROP)/linux_intel64_$(TBB_COMPILER_STR)_$(TBB_C_LIB_STR)_kernel$(TBB_KERNEL_STR)_debug
endif
$(shell mkdir -p $(X_REL) $(X_DEB))
TBB_LIB_PATH_RELEASE:=$(realpath $(X_REL))
TBB_LIB_PATH_DEBUG:=$(realpath $(X_DEB))
TBB_LIB_RELEASE=$(TBB_LIB_PATH_RELEASE)/libtbb.so
TBB_LIB_DEBUG=$(TBB_LIB_PATH_DEBUG)/libtbb_debug.so
TBB_RELEASE_LIBRARIES:=-L$(TBB_LIB_PATH_RELEASE) -ltbb -ltbbmalloc -ltbbmalloc_proxy
TBB_DEBUG_LIBRARIES:=-L$(TBB_LIB_PATH_DEBUG) -ltbb_debug -ltbbmalloc_debug -ltbbmalloc_proxy_debug

ifdef NDEBUG
    TBB_LIBRARIES_ROOT:=$(TBB_LIB_PATH_RELEASE)
    TBB_LIBRARIES:=-L$(TBB_LIBRARIES_ROOT) $(TBB_RELEASE_LIBRARIES)
else
    TBB_LIBRARIES_ROOT:=$(TBB_LIB_PATH_DEBUG)
    TBB_LIBRARIES:=$(TBB_DEBUG_LIBRARIES)
endif

TBB_RPATH:=-Wl,-rpath=$(TBB_LIBRARIES_ROOT) -Wl,-rpath-link=$(TBB_LIBRARIES_ROOT)

LDFLAGS:=-L$(BUILD_TOOLS_LIB) -L$(TOOL_CHAIN_LIB) -L$(TOOL_CHAIN_LIB64) $(SANITIZER_LIB) -L$(TBB_LIBRARIES_ROOT) $(TBB_LIBRARIES)
LDFLAGS_RPATH:=-Wl,-rpath=$(BUILD_TOOLS_LIB) -Wl,-rpath-link=$(BUILD_TOOLS_LIB)
LDFLAGS_RPATH+=$(TOOL_CHAIN_RPATH) $(BUILD_TOOLS_RPATH) $(TBB_RPATH)

COLOR_DIAGNOSTICS?=-fdiagnostics-color=auto

WARN_FLAGS:=-Wall -Wextra -Wformat=2 -Wdeprecated -Wno-unused-local-typedefs -Wno-pragmas $(COLOR_DIAGNOSTICS)
C_WARN_FLAGS:=-Wall -Wextra -Wformat=2 -Wdeprecated $(COLOR_DIAGNOSTICS)
DEBUG_FLAGS:=-ggdb -O0 -fno-omit-frame-pointer -fstack-protector-all -fstack-protector-strong $(SANITIZER)
CFLAGS:=$(CLANG) -fPIC -DPIC $(DEBUG_FLAGS) $(C_WARN_FLAGS)
CXXFLAGS:=$(CPPLANG) -pedantic -fPIC -DPIC $(DEBUG_FLAGS) $(WARN_FLAGS) $(BUGS)
CPPFLAGS:=-pthread -DJSON_ISO_STRICT -DJSON_DEBUG -UJSON_SAFE -I$(TOOL_CHAIN_INCLUDE) -I$(BUILD_TOOLS_INC) 

export

